
from .utils import get_path_to_home_of_google_drive, get_path_to_home_of_local_machine
from .google_drive import mount_google_drive, is_google_drive_mounted
from .transfer import  copy_file, copy_folder_structure


from pathlib import Path

from colab_transfer.utils import get_path_to_root_of_google_drive

try:
    from google.colab import drive
except ModuleNotFoundError:
    pass


def mount_google_drive():
    try:
        drive.mount(get_path_to_root_of_google_drive())
    except NameError:
        print('Google Drive cannot be mounted. Please ensure that a session of Colaboratory is running.')

    return


def is_google_drive_mounted():
    google_drive_is_mounted = Path(get_path_to_root_of_google_drive()).exists()

    return google_drive_is_mounted


def main():
    mount_google_drive()

    print('Is Google Drive mounted? {}'.format(is_google_drive_mounted()))

    return True


if __name__ == '__main__':
    main()



def get_path_to_root():
    path_to_root = '/content/'

    return path_to_root


def get_path_to_root_of_google_drive():
    path_to_root_of_google_drive = get_path_to_root() + 'drive/'

    return path_to_root_of_google_drive


def get_path_to_home_of_local_machine():
    path_to_home_of_local_machine = get_path_to_root()

    return path_to_home_of_local_machine


def get_path_to_home_of_google_drive():
    path_to_home_of_google_drive = get_path_to_root_of_google_drive() + 'My Drive/'

    return path_to_home_of_google_drive


def main():
    for folder in [
        get_path_to_root(),
        get_path_to_root_of_google_drive(),
        get_path_to_home_of_local_machine(),
        get_path_to_home_of_google_drive(),
    ]:
        print('Folder: {}'.format(folder))

    return True


if __name__ == '__main__':
    main()



from distutils.core import setup

# noinspection PyUnresolvedReferences
import setuptools

setup(
    name='Google Colab Transfer',
    packages=['colab_transfer'],
    install_requires=[
    ],
    test_suite='nose.collector',
    tests_require=['nose'],
    version='0.1.3',
    description='Transfer data between Colab and Drive.',
    long_description='Transfer data between Colab and Drive.',
    long_description_content_type='text/x-rst',
    author='Wok',
    author_email='wok@tuta.io',
    url='https://github.com/woctezuma/google-colab-transfer',
    download_url='https://github.com/woctezuma/google-colab-transfer/archive/0.1.3.tar.gz',
    keywords=['google-colab', 'google-colaboratory', 'google-drive'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)




import glob
import os
import shutil
from pathlib import Path

from colab_transfer.utils import get_path_to_home_of_google_drive, get_path_to_home_of_local_machine


def copy_file(file_name,
              source=None,
              destination=None,
              verbose=True):
    if source is None:
        source = get_path_to_home_of_google_drive()

    if destination is None:
        destination = get_path_to_home_of_local_machine()
    else:
        Path(destination).mkdir(parents=True, exist_ok=True)

    input_file_name = source + file_name
    output_file_name = destination + file_name

    if Path(output_file_name).exists():
        if verbose:
            print('File {} already exists. Copy skipped.'.format(output_file_name))
    else:
        if verbose:
            print('Copying {} to {}'.format(input_file_name,
                                            output_file_name))

        try:
            shutil.copyfile(input_file_name,
                            output_file_name)
        except FileNotFoundError:
            print('File {} could not be found. Copy aborted.'.format(input_file_name))

    return


def copy_folder(folder_name,
                source=None,
                destination=None,
                verbose=True):
    if source is None:
        source = get_path_to_home_of_google_drive()

    if destination is None:
        destination = get_path_to_home_of_local_machine()
    else:
        Path(destination).mkdir(parents=True, exist_ok=True)

    input_folder_name = source + folder_name
    output_folder_name = destination + folder_name

    if Path(output_folder_name).exists():
        if verbose:
            print('Folder {} already exists. Copy skipped.'.format(output_folder_name))
    else:
        if verbose:
            print('Copying {} to {}'.format(input_folder_name,
                                            output_folder_name))

        try:
            shutil.copytree(src=input_folder_name,
                            dst=output_folder_name)
        except FileNotFoundError:
            print('Folder {} could not be found. Copy aborted.'.format(input_folder_name))

    return


def copy_folder_structure(source=None,
                          destination=None,
                          verbose=True):
    if source is None:
        source = get_path_to_home_of_google_drive()

    if destination is None:
        destination = get_path_to_home_of_local_machine()
    else:
        Path(destination).mkdir(parents=True, exist_ok=True)

    files_and_folders = glob.glob(source + '*')

    root_files = glob.glob(source + '*.*')
    root_folders = set(files_and_folders).difference(root_files)

    if verbose:
        print('Files: {}'.format(root_files))
        print('Folders: {}'.format(root_folders))

    for f_name in root_files:
        file_name = os.path.basename(f_name)

        copy_file(file_name,
                  source=source,
                  destination=destination,
                  verbose=verbose)

    for f_name in root_folders:
        folder_name = os.path.basename(f_name) + '/'

        copy_folder(folder_name,
                    source=source,
                    destination=destination,
                    verbose=verbose)

    return


def main():
    return True


if __name__ == '__main__':
    main()
